@@ -17,6 +17,7 @@ use Scalar::Util qw(reftype);
 our $ENCODE_UTF8   = 0;
 our $SANITIZE_UTF8 = 0;
 our $FORCE_UNTAINT = 0;
+our $PRESERVE_UTF8 = 0;
 
 =head1 Methods
 
@@ -79,7 +80,7 @@ sub bind {
                     $engine->property_by_path($path, $$text_ref);
                 } else {
                     JavaScript::SpiderMonkey::JS_DefineProperty(
-                        $engine->{engine}, $obj, $name, $$text_ref);
+                        $engine->{context}, $obj, $name, $$text_ref);
                 }
             }
         }
@@ -108,7 +109,7 @@ sub bind {
 
 sub DESTROY {
     my ($self) = @_;
-    $self->{engine}->destroy();
+    $self->{engine}->destroy() if $self->{engine};
     delete $self->{engine};
 }
 
